@@ -5,6 +5,7 @@ from .feature_selection_cross_validation_task import FeatureSelectionCrossValida
 from .hyperparameters_search_cross_validation_task import HyperParametersSearchCrossValidationTask
 from .train_task import TrainTask
 from .prediction_task import PredictionTask
+from .deep_feature_synthesis_task import DeepFeatureSynthesisTask
 
 __all__ = [
     "BaseTask",
@@ -13,5 +14,6 @@ __all__ = [
     "FeatureSelectionCrossValidationTask",
     "HyperParametersSearchCrossValidationTask",
     "TrainTask",
-    "PredictionTask"
+    "PredictionTask",
+    "DeepFeatureSynthesisTask"
 ]
\ No newline at end of file
